"use strict";
const fs_extra_1 = require("fs-extra");
const fs_tree_utils_1 = require("fs-tree-utils");
const contants_1 = require("../../contants");
/**
 * List compiled products corresponding to source files inside `root`
 * @param root Directory that contains all source files
 * @param options Options
 * @param options.deep A function that tells when to go deeper
 * @param options.isSource A function that tells which file is a source file
 * @param options.listTargets A function that lists compiled products corresponding to a source file
 * @returns A promise that resolves a list of target file paths
 */
async function listAllTargets(root, options = {}) {
    const { deep = contants_1.DEFAULT_DEEP_FUNC, isSource = contants_1.DEFAULT_SOURCE_DETECTOR, listTargets = contants_1.DEFAULT_TARGET_SPECIFIER } = options;
    const existed = (await fs_tree_utils_1.traverse(root, { deep, stat: fs_extra_1.lstat }))
        .filter(isSource)
        .map(listTargets)
        .reduce((prev, current) => [...prev, ...current], [])
        .filter(item => fs_extra_1.existsSync(item));
    const files = (await Promise.all(existed.map(async (item) => ({
        item,
        stats: await fs_extra_1.lstat(item)
    }))))
        .filter(x => x.stats.isFile())
        .map(x => x.item);
    return files;
}
module.exports = listAllTargets;
//# sourceMappingURL=index.js.map